@@ -31,6 +31,10 @@ struct ObjectField {
     rename: Option<String>,
     #[darling(default)]
     default: Option<DefaultValue>,
+    #[darling(default)]
+    write_only: bool,
+    #[darling(default)]
+    read_only: bool,
 
     #[darling(default)]
     multiple_of: Option<SpannedValue<f64>>,
@@ -101,6 +105,8 @@ pub(crate) fn generate(args: DeriveInput) -> GeneratorResult<TokenStream> {
     for field in &s.fields {
         let field_ident = field.ident.as_ref().unwrap();
         let field_ty = &field.ty;
+        let read_only = field.read_only;
+        let write_only = field.write_only;
 
         if field.skip {
             deserialize_fields.push(quote! {
@@ -110,6 +116,14 @@ pub(crate) fn generate(args: DeriveInput) -> GeneratorResult<TokenStream> {
             continue;
         }
 
+        if read_only && write_only {
+            return Err(Error::new_spanned(
+                field_ident,
+                "The `write_only` and `read_only` attributes cannot be enabled both.",
+            )
+            .into());
+        }
+
         let field_name = field.rename.clone().unwrap_or_else(|| {
             args.rename_all
                 .rename(field_ident.unraw().to_string(), RenameTarget::Field)
@@ -124,16 +138,27 @@ pub(crate) fn generate(args: DeriveInput) -> GeneratorResult<TokenStream> {
 
         fields.push(field_ident);
 
-        match &field.default {
-            Some(default_value) => {
-                let default_value = match default_value {
-                    DefaultValue::Default => {
-                        quote!(<#field_ty as ::std::default::Default>::default())
+        if read_only {
+            deserialize_fields.push(quote! {
+                #[allow(non_snake_case)]
+                let #field_ident: #field_ty = {
+                    if obj.contains_key(#field_name) {
+                        return Err(#crate_name::types::ParseError::custom(format!("properties `{}` is read only.", #field_name)));
                     }
-                    DefaultValue::Function(func_name) => quote!(#func_name()),
+                    Default::default()
                 };
+            });
+        } else {
+            match &field.default {
+                Some(default_value) => {
+                    let default_value = match default_value {
+                        DefaultValue::Default => {
+                            quote!(<#field_ty as ::std::default::Default>::default())
+                        }
+                        DefaultValue::Function(func_name) => quote!(#func_name()),
+                    };
 
-                deserialize_fields.push(quote! {
+                    deserialize_fields.push(quote! {
                     #[allow(non_snake_case)]
                     let #field_ident: #field_ty = {
                         match obj.get(#field_name).cloned().unwrap_or_default() {
@@ -146,9 +171,9 @@ pub(crate) fn generate(args: DeriveInput) -> GeneratorResult<TokenStream> {
                         }
                     };
                 });
-            }
-            _ => {
-                deserialize_fields.push(quote! {
+                }
+                _ => {
+                    deserialize_fields.push(quote! {
                     #[allow(non_snake_case)]
                     let #field_ident: #field_ty = {
                         let value = #crate_name::types::ParseFromJSON::parse_from_json(obj.get(#field_name).cloned().unwrap_or_default())
@@ -157,13 +182,18 @@ pub(crate) fn generate(args: DeriveInput) -> GeneratorResult<TokenStream> {
                         value
                     };
                 });
-            }
-        };
+                }
+            };
+        }
 
-        serialize_fields.push(quote! {
-            let value = #crate_name::types::ToJSON::to_json(&self.#field_ident);
-            object.insert(::std::string::ToString::to_string(#field_name), value);
-        });
+        if write_only {
+            serialize_fields.push(quote! {});
+        } else {
+            serialize_fields.push(quote! {
+                let value = #crate_name::types::ToJSON::to_json(&self.#field_ident);
+                object.insert(::std::string::ToString::to_string(#field_name), value);
+            });
+        }
 
         let field_meta_default = match &field.default {
             Some(DefaultValue::Default) => {
@@ -178,10 +208,11 @@ pub(crate) fn generate(args: DeriveInput) -> GeneratorResult<TokenStream> {
         meta_fields.push(quote! {{
             <#field_ty>::register(registry);
 
-            let mut schema_ref = <#field_ty as #crate_name::types::Type>::schema_ref();
-
-            if let #crate_name::registry::MetaSchemaRef::Inline(schema) = &mut schema_ref {
+            let patch_schema = {
+                let mut schema = #crate_name::registry::MetaSchema::ANY;
                 schema.default = #field_meta_default;
+                schema.read_only = #read_only;
+                schema.write_only = #write_only;
 
                 if let ::std::option::Option::Some(title) = #field_title {
                     schema.title = ::std::option::Option::Some(title);
@@ -191,9 +222,10 @@ pub(crate) fn generate(args: DeriveInput) -> GeneratorResult<TokenStream> {
                     schema.description = ::std::option::Option::Some(field_description);
                 }
                 #validators_update_meta
-            }
+                schema
+            };
 
-            (#field_name, schema_ref)
+            (#field_name, <#field_ty as #crate_name::types::Type>::schema_ref().merge(patch_schema))
         }});
 
         required_fields.push(quote! {
